@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import itertools
 import logging
 import os.path as osp
@@ -147,7 +148,7 @@ class LVISV05Dataset(CocoDataset):
         'life_jacket', 'lightbulb', 'lightning_rod', 'lime', 'limousine',
         'linen_paper', 'lion', 'lip_balm', 'lipstick', 'liquor', 'lizard',
         'Loafer_(type_of_shoe)', 'log', 'lollipop', 'lotion',
-        'speaker_(stero_equipment)', 'loveseat', 'machine_gun', 'magazine',
+        'speaker_(stereo_equipment)', 'loveseat', 'machine_gun', 'magazine',
         'magnet', 'mail_slot', 'mailbox_(at_home)', 'mallet', 'mammoth',
         'mandarin_orange', 'manger', 'manhole', 'map', 'marker', 'martini',
         'mascot', 'mashed_potato', 'masher', 'mask', 'mast',
@@ -594,7 +595,7 @@ class LVISV1Dataset(LVISDataset):
         'legging_(clothing)', 'Lego', 'legume', 'lemon', 'lemonade', 'lettuce',
         'license_plate', 'life_buoy', 'life_jacket', 'lightbulb',
         'lightning_rod', 'lime', 'limousine', 'lion', 'lip_balm', 'liquor',
-        'lizard', 'log', 'lollipop', 'speaker_(stero_equipment)', 'loveseat',
+        'lizard', 'log', 'lollipop', 'speaker_(stereo_equipment)', 'loveseat',
         'machine_gun', 'magazine', 'magnet', 'mail_slot', 'mailbox_(at_home)',
         'mallard', 'mallet', 'mammoth', 'manatee', 'mandarin_orange', 'manger',
         'manhole', 'map', 'marker', 'martini', 'mascot', 'mashed_potato',
